@@ -14,15 +14,17 @@ isSubset.boolmat <- function(A){
     if (nrow(A)==1) return(FALSE)
 
     d <- duplicated(A)
+    wd <- which(d)
     m <- nrow(A)
     if ( m == 0 ) return(logical(0))
     M <- (1:m)[!d]
     if ( length(M) == 1 ) return(d)
     m1 <- length(M)-1
-    s <- vapply(
-        M, 
+    s <- logical(m)
+    s[M] <- vapply(M, 
         function(i){
-            any(rowSums(A[-i,,drop=FALSE] - (A[-i,,drop=FALSE]) | A[rep(i,m1),,drop=FALSE] ) == 0)
+            I <- c(i,wd)
+            any(rowSums(A[-I,,drop=FALSE] - (A[-I,,drop=FALSE] | A[rep(i,m1),,drop=FALSE]) ) == 0)
         },
         FUN.VALUE=FALSE 
     )
