@@ -33,6 +33,11 @@ test_that("parse editarray to character and back",{
     expect_equivalent(editarray(edts), editarray(as.character(editarray(edts))))
 })
 
-
-
-
+test_that("parse editarray to expression and back",{
+  edts <- expression(
+    g %in% c('m','f'),
+    p %in% c(FALSE,TRUE),
+    if (p) !g=='m'
+    )
+  expect_equivalent(editarray(edts), editarray(as.character(editarray(edts))))
+})
